.. _simplerepl:

A Simple REPL
=============

The following code listing shows a simple example REPL implemented using `bpython` and `curtsies`.

.. literalinclude:: simplerepl.py
   :language: python
